(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    110209,       2379]*)
(*NotebookOutlinePosition[    110935,       2404]*)
(*  CellTagsIndexPosition[    110891,       2400]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["MmaGMDH", "Title"],

Cell[TextData[{
  "MmaGMDH is a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " program for the implementation of the traditional GMDH algorithm.\n\nFor \
more on the GMDH see:\nhttp://www.GMDH.net\n\nMmaGMDH utilizes the power \
inherent in ",
  StyleBox["Mathematica'",
    FontSlant->"Italic"],
  "s Functional Programming language, resulting in a revolutionary \
implementation of the GMDH algorithm.  In a few lines of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " code MmaGMDH produces both numeric and symbolic solutions for the GMDH.  \
An option is provided that allows the user to turn off the generation of a \
symbolic solution - allowing for faster solution times when only numeric \
results are necessary.\n\nAll of the intermediate results for the GMDH \
solution are available for \"interactive\" post processing.\n\nThe data sets \
that need to be initialized are as follows:\n\nxtr[1]\tInput training data. \t\
\t{{xtr_1},{xtr_2},...,{xtr_m}}\nxte[1]\tInput testing data. \t\t\
{{xte_1},{xte_2},...,{xte_m}}\nxva[1]  Validation data. \t\t\
{{xva_1},{xva_2},...,{xva_m}}\nztr\tOutput training data.\t\t{ztr}\nzte\t\
Output testing data.\t\t{zte}\nzva\tOutput validation data.\t\t{zva}\n\nWhere \
\"m\" is the number of inputs and: \n\tLength[xtr_i]=Length[ztr] = number of \
training data for fitting nodal surfaces using least squares.\n\t\
Length[xte_i]=Length[zte] =number of testing data for pruning nodes at each \
layer.\n\tLength[xva_i]=Length[zva]=number of validation data.\n\nAn example \
for using the MmGMDH is provided that utilizes Jerome Friedman's \"add10\" \
database. \n\nDescription of add10 database: \nThe synthetic dataset \
\"add10\" uses a function suggested by Jerome Friedman in \"Multivariate \
Adaptive Regression Splines\", technical Report No. 102, November 1988, \
Laboratory for Computational Statistics, Department of Statistics, Stanford \
University. \n\nThe function is: \nf(x1,...,x10) = 10*sin(pi*x1*x2) + \
20*(x3-0.5)^2 + 10*x4 + 5*x5 + n, where n is zero mean unit variance Gaussian \
noise. The inputs x1...x10 are sampled independently from a uniform [0; 1] \
distribution. \n\nThe \"add10\" dataset is intended to provide an example \
where some inputs are irrelevant for predictions and where the function has a \
predominantly additive structure. \n\nNumber of instances: 8181.\n\nsee: \n\
http://www.work.caltech.edu/cs156/96/projects/optimization/add10.html\n\
http://www.cs.toronto.edu/~delve/data/add10/desc.html\n\nNote: The average \
value for the sum-squared-error over the validation set of 3.65  (Layer 4) \
compares favorably with the value 3.9 reported in:\nVoss, M.S. (2003) \
\"Social Programming on MARS\", \nProceedings 2003 Genetic and Evolutionary \
Computation Conference,\nJuly 12-16, Chicago, Illinois (Late Breaking \
Papers). \n\nsee:\n\
http://www.evolutionarystructures.com/papers/voss_gecco2003.pdf\n\nMmaGMDH \
\[Copyright] Copyright Dr. Mark S. Voss, September, 2003. \nAll rights \
reserved.\n\nPlease send any comments/corrections or extensions of MmaGMDH \
to: \n",
  StyleBox["MarkVoss@EvolutionaryStructures.com\n\n",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  "Any submitted comments/corrections/improved versions, will be review and \
posted to www.gmdh.net per webmaster approval."
}], "Text"],

Cell[CellGroupData[{

Cell["Import \"add10.dat\" and initialize global data sets.", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\(SetDirectory["\<D:\\MmaGMDH2\>"];\)\
\[IndentingNewLine]
    \(data1 = Import["\<add10.dat\>", "\<Table\>"];\)\[IndentingNewLine]
    Length@data1\[IndentingNewLine]
    \(data2 = Take[data1, 1400];\)\[IndentingNewLine]
    \(zdata = \(#[\([11]\)] &\) /@ \ data2;\)\[IndentingNewLine]
    \(xdata = \(Take[#, {1, 10}] &\)\  /@ \ data2;\)\)\)\)], "Input"],

Cell[BoxData[
    \(8181\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\(xtr[1] = 
        Transpose@Take[xdata, {1, 200}];\)\[IndentingNewLine]
    \(xte[1] = Transpose@Take[xdata, {201, 400}];\)\[IndentingNewLine]
    \(xva[1] = Transpose@Take[xdata, {401, 1400}];\)\[IndentingNewLine]
    \(ztr = Take[zdata, {1, 200}];\)\[IndentingNewLine]
    \(zte = Take[zdata, {201, 400}];\)\[IndentingNewLine]
    \(zva = Take[zdata, {401, 1400}];\)\)\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MmaGMDH - Module and Function Definitions.", "Section"],

Cell[BoxData[{
    RowBox[{\(GMDHleastSquares[{x_, y_, z_}] := 
        Module[{o, Y, A, b, a}, \[IndentingNewLine]o = 
            Table[1, {Length[x]}]; \[IndentingNewLine]Y = {o, x, y, x\ y, 
              x\ x, y\ y}; \[IndentingNewLine]A = 
            Y . Transpose[Y]; \[IndentingNewLine]b = 
            z . Transpose[Y]; \[IndentingNewLine]a = LinearSolve[A, b]]\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(GMDHerror[{x_, y_, z_, a_}] := 
        Module[{xy, zp, e}, \[IndentingNewLine]xy = 
            Transpose[{x, 
                y}]; \[IndentingNewLine]zp = \(\((a[\([1]\)] + 
                    a[\([2]\)] #[\([1]\)] + a[\([3]\)] #[\([2]\)] + 
                    a[\([4]\)] #[\([1]\)] #[\([2]\)] + 
                    a[\([5]\)] #[\([1]\)]^2 + a[\([6]\)] #[\([2]\)]^2)\) &\) /@ 
              xy; \[IndentingNewLine]e = z - zp; \[IndentingNewLine]{e . e, 
            zp}\ ]\), "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(Nchoose2[n_]\), ":=", 
        RowBox[{"Module", "[", 
          RowBox[{\({t1, t2, t3, t4}\), ",", 
            StyleBox["\[IndentingNewLine]",
              FormatType->StandardForm], 
            
            StyleBox[\(t = Range[n]\ ; \ 
              t1 = Flatten[Outer[List, t, t], 1]; \ t2 = Map[Sort, t1]; \ 
              t3 = Union[t2]; \ \[IndentingNewLine]t4 = 
                Cases[t3, {x_, y_} /; \((x =!= y)\)]\),
              FormatType->StandardForm]}], 
          StyleBox[" ",
            FormatType->StandardForm], 
          StyleBox["]",
            FormatType->StandardForm]}]}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(GMDHpoly[{x_, y_}, a_] := 
        a[\([1]\)] + a[\([2]\)] x + a[\([3]\)] y + a[\([4]\)] x\ y + 
          a[\([5]\)] x^2 + a[\([6]\)] y^2\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(GMDHeval[n_, xv_] := \(xso[n]\)[\([1]\)] /. 
          MapThread[\((#1 \[Rule] #2)\) &, {xso[0], xv}]\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(GMDH[numLayers_, 
        option_] := 
      Module[{nunInputs, nc2, rngnc2}, \[IndentingNewLine]numInputs = 
          Length[xtr[1]]; \[IndentingNewLine]nc2 = 
          Nchoose2[numInputs]; \[IndentingNewLine]rngnc2 = 
          Range@Length[nc2]; \[IndentingNewLine]xso[0] = 
          Table[ToExpression[StringJoin["\<x\>" <> ToString[i]]], {i, 1, 
              numInputs}]; \[IndentingNewLine]Table[\[IndentingNewLine]tr[
              i] = \(Part[xtr[i], #] &\)\  /@ \ nc2; \[IndentingNewLine]te[
              i] = \(Part[xte[i], #] &\)\ \  /@ nc2; \[IndentingNewLine]va[
              i] = \(Part[xva[i], #] &\)\ \  /@ nc2; \[IndentingNewLine]av[
              i] = \(GMDHleastSquares[{#[\([1]\)], #[\([2]\)], 
                    ztr}] &\)\  /@ \ tr[i]; \[IndentingNewLine]trer[i] = 
            MapThread[
              GMDHerror[\ {#1[\([1]\)], #1[\([2]\)], ztr, #2}] &, {tr[i], 
                av[i]}]; \[IndentingNewLine]teer[i] = 
            MapThread[
              GMDHerror[\ {#1[\([1]\)], #1[\([2]\)], zte, #2}] &, {\ te[i], 
                av[i]}]; \[IndentingNewLine]vaer[i] = 
            MapThread[
              GMDHerror[\ {#1[\([1]\)], #1[\([2]\)], zva, #2}] &, {\ va[i], 
                av[i]}]; \[IndentingNewLine]trfit[i] = 
            Sort@Thread[{\(#[\([1]\)] &\) /@ trer[i], 
                  rngnc2}]; \[IndentingNewLine]tefit[i] = 
            Sort@Thread[{\(#[\([1]\)] &\) /@ teer[i], 
                  rngnc2}]; \[IndentingNewLine]vafit[i] = 
            Sort@Thread[{\(#[\([1]\)] &\) /@ vaer[i], 
                  rngnc2}]; \[IndentingNewLine]inputs[i] = 
            Take[\(#[\([2]\)] &\) /@ tefit[i], 
              numInputs]; \[IndentingNewLine]xtr[i + 1] = 
            Part[\(#[\([2]\)] &\) /@ trer[i], 
              inputs[i]]; \[IndentingNewLine]xte[i + 1] = 
            Part[\(#[\([2]\)] &\) /@ teer[i], 
              inputs[i]]; \[IndentingNewLine]xva[i + 1] = 
            Part[\(#[\([2]\)] &\) /@ vaer[i], 
              inputs[i]]; \[IndentingNewLine]If[
            Symbolic /. 
              option, \[IndentingNewLine]xsi[
                i] = \(Part[xso[i - 1], #] &\)\  /@ \ 
                Part[nc2, inputs[i]]; \[IndentingNewLine]xso[i] = 
              MapThread[
                GMDHpoly, {xsi[i], 
                  Part[av[i], 
                    inputs[i]]}];\[IndentingNewLine]]; \
\[IndentingNewLine]Print["\<Layer=\>", i]\[IndentingNewLine], {i, 1, 
            numLayers}];\[IndentingNewLine]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
GMDH run with timing (8 layers with symbolic solution turned off)\
\>", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Timing[GMDH[numLayers = 8, Symbolic -> False]]\)[\([1]\)]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Layer="\[InvisibleSpace]1\),
      SequenceForm[ "Layer=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Layer="\[InvisibleSpace]2\),
      SequenceForm[ "Layer=", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Layer="\[InvisibleSpace]3\),
      SequenceForm[ "Layer=", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Layer="\[InvisibleSpace]4\),
      SequenceForm[ "Layer=", 4],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Layer="\[InvisibleSpace]5\),
      SequenceForm[ "Layer=", 5],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Layer="\[InvisibleSpace]6\),
      SequenceForm[ "Layer=", 6],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Layer="\[InvisibleSpace]7\),
      SequenceForm[ "Layer=", 7],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Layer="\[InvisibleSpace]8\),
      SequenceForm[ "Layer=", 8],
      Editable->False]], "Print"],

Cell[BoxData[
    \(3.547000000000004`\ Second\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
GMDH run with timing (8 layers with symbolic solution turned on)\
\>", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Timing[GMDH[numLayers = 8, Symbolic -> True]]\)[\([1]\)]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Layer="\[InvisibleSpace]1\),
      SequenceForm[ "Layer=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Layer="\[InvisibleSpace]2\),
      SequenceForm[ "Layer=", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Layer="\[InvisibleSpace]3\),
      SequenceForm[ "Layer=", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Layer="\[InvisibleSpace]4\),
      SequenceForm[ "Layer=", 4],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Layer="\[InvisibleSpace]5\),
      SequenceForm[ "Layer=", 5],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Layer="\[InvisibleSpace]6\),
      SequenceForm[ "Layer=", 6],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Layer="\[InvisibleSpace]7\),
      SequenceForm[ "Layer=", 7],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Layer="\[InvisibleSpace]8\),
      SequenceForm[ "Layer=", 8],
      Editable->False]], "Print"],

Cell[BoxData[
    \(8.672000000000004`\ Second\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot of test,training and validation errors.", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(Table[\(tefit[i]\)[\([1, 1]\)], {i, 1, 
        numLayers}]\[IndentingNewLine]
    \(ListPlot[%, 
        PlotJoined \[Rule] True];\)\[IndentingNewLine]\[IndentingNewLine]
    Table[\(trfit[i]\)[\([1, 1]\)], {i, 1, numLayers}]\[IndentingNewLine]
    \(ListPlot[%, 
        PlotJoined \[Rule] True];\)\[IndentingNewLine]\[IndentingNewLine]
    Table[\(vafit[i]\)[\([1, 1]\)], {i, 1, numLayers}]\[IndentingNewLine]
    \(ListPlot[%, PlotJoined \[Rule] True];\)\)\)\)], "Input"],

Cell[BoxData[
    \({2325.174746061245`, 1060.5007364581616`, 763.5579377487547`, 
      735.4253164970683`, 724.190250710136`, 710.6848848153854`, 
      697.7814618561507`, 684.1655448676001`}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112245 0.136054 -0.230684 0.000358684 [
[.15986 .02583 -3 -9 ]
[.15986 .02583 3 0 ]
[.29592 .02583 -3 -9 ]
[.29592 .02583 3 0 ]
[.43197 .02583 -3 -9 ]
[.43197 .02583 3 0 ]
[.56803 .02583 -3 -9 ]
[.56803 .02583 3 0 ]
[.70408 .02583 -3 -9 ]
[.70408 .02583 3 0 ]
[.84014 .02583 -3 -9 ]
[.84014 .02583 3 0 ]
[.97619 .02583 -3 -9 ]
[.97619 .02583 3 0 ]
[.01131 .128 -24 -4.5 ]
[.01131 .128 0 4.5 ]
[.01131 .21767 -24 -4.5 ]
[.01131 .21767 0 4.5 ]
[.01131 .30734 -24 -4.5 ]
[.01131 .30734 0 4.5 ]
[.01131 .39701 -24 -4.5 ]
[.01131 .39701 0 4.5 ]
[.01131 .48668 -24 -4.5 ]
[.01131 .48668 0 4.5 ]
[.01131 .57635 -24 -4.5 ]
[.01131 .57635 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 .03833 m
.15986 .04458 L
s
[(2)] .15986 .02583 0 1 Mshowa
.29592 .03833 m
.29592 .04458 L
s
[(3)] .29592 .02583 0 1 Mshowa
.43197 .03833 m
.43197 .04458 L
s
[(4)] .43197 .02583 0 1 Mshowa
.56803 .03833 m
.56803 .04458 L
s
[(5)] .56803 .02583 0 1 Mshowa
.70408 .03833 m
.70408 .04458 L
s
[(6)] .70408 .02583 0 1 Mshowa
.84014 .03833 m
.84014 .04458 L
s
[(7)] .84014 .02583 0 1 Mshowa
.97619 .03833 m
.97619 .04458 L
s
[(8)] .97619 .02583 0 1 Mshowa
.125 Mabswid
.05102 .03833 m
.05102 .04208 L
s
.07823 .03833 m
.07823 .04208 L
s
.10544 .03833 m
.10544 .04208 L
s
.13265 .03833 m
.13265 .04208 L
s
.18707 .03833 m
.18707 .04208 L
s
.21429 .03833 m
.21429 .04208 L
s
.2415 .03833 m
.2415 .04208 L
s
.26871 .03833 m
.26871 .04208 L
s
.32313 .03833 m
.32313 .04208 L
s
.35034 .03833 m
.35034 .04208 L
s
.37755 .03833 m
.37755 .04208 L
s
.40476 .03833 m
.40476 .04208 L
s
.45918 .03833 m
.45918 .04208 L
s
.48639 .03833 m
.48639 .04208 L
s
.51361 .03833 m
.51361 .04208 L
s
.54082 .03833 m
.54082 .04208 L
s
.59524 .03833 m
.59524 .04208 L
s
.62245 .03833 m
.62245 .04208 L
s
.64966 .03833 m
.64966 .04208 L
s
.67687 .03833 m
.67687 .04208 L
s
.73129 .03833 m
.73129 .04208 L
s
.7585 .03833 m
.7585 .04208 L
s
.78571 .03833 m
.78571 .04208 L
s
.81293 .03833 m
.81293 .04208 L
s
.86735 .03833 m
.86735 .04208 L
s
.89456 .03833 m
.89456 .04208 L
s
.92177 .03833 m
.92177 .04208 L
s
.94898 .03833 m
.94898 .04208 L
s
.25 Mabswid
0 .03833 m
1 .03833 L
s
.02381 .128 m
.03006 .128 L
s
[(1000)] .01131 .128 1 0 Mshowa
.02381 .21767 m
.03006 .21767 L
s
[(1250)] .01131 .21767 1 0 Mshowa
.02381 .30734 m
.03006 .30734 L
s
[(1500)] .01131 .30734 1 0 Mshowa
.02381 .39701 m
.03006 .39701 L
s
[(1750)] .01131 .39701 1 0 Mshowa
.02381 .48668 m
.03006 .48668 L
s
[(2000)] .01131 .48668 1 0 Mshowa
.02381 .57635 m
.03006 .57635 L
s
[(2250)] .01131 .57635 1 0 Mshowa
.125 Mabswid
.02381 .05626 m
.02756 .05626 L
s
.02381 .0742 m
.02756 .0742 L
s
.02381 .09213 m
.02756 .09213 L
s
.02381 .11007 m
.02756 .11007 L
s
.02381 .14593 m
.02756 .14593 L
s
.02381 .16387 m
.02756 .16387 L
s
.02381 .1818 m
.02756 .1818 L
s
.02381 .19974 m
.02756 .19974 L
s
.02381 .23561 m
.02756 .23561 L
s
.02381 .25354 m
.02756 .25354 L
s
.02381 .27147 m
.02756 .27147 L
s
.02381 .28941 m
.02756 .28941 L
s
.02381 .32528 m
.02756 .32528 L
s
.02381 .34321 m
.02756 .34321 L
s
.02381 .36114 m
.02756 .36114 L
s
.02381 .37908 m
.02756 .37908 L
s
.02381 .41495 m
.02756 .41495 L
s
.02381 .43288 m
.02756 .43288 L
s
.02381 .45082 m
.02756 .45082 L
s
.02381 .46875 m
.02756 .46875 L
s
.02381 .50462 m
.02756 .50462 L
s
.02381 .52255 m
.02756 .52255 L
s
.02381 .54049 m
.02756 .54049 L
s
.02381 .55842 m
.02756 .55842 L
s
.02381 .02039 m
.02756 .02039 L
s
.02381 .00246 m
.02756 .00246 L
s
.02381 .59429 m
.02756 .59429 L
s
.02381 .61222 m
.02756 .61222 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.15986 .1497 L
.29592 .04319 L
.43197 .0331 L
.56803 .02907 L
.70408 .02423 L
.84014 .0196 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00F`3oool600000380oooo1000
000c0?ooo`@00000<@3oool4000003@0oooo1000000c0?ooo`030000003oool0oooo0340oooo1000
000:0?ooo`00F`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`3oool002P0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool002P0oooo0`00000b0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0;P3oool6000003D0oooo00<000000?ooo`3o
ool0<03oool2000000<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool002P0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0d0?ooo`800000<P3oool010000000oooo0?ooo`00000f0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`0000000P00000d0?ooo`030000003oool0oooo0300
oooo1000000:0?ooo`00:03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0;`3oool010000000oooo0?ooo`00000b0?ooo`@00000<`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`00:03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0`0?ooo`030000003oool000000380oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`00:03oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0300oooo00<000000?ooo`000000<P3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool002P0oooo00<00000
0?ooo`3oool0<@3oool4000003<0oooo1000000d0?ooo`800000<P3oool5000003D0oooo0`00000_
0?ooo`H000009`3oool>000000X0oooo000X0?ooo`030000003oool0oooo0?l0ooooD`3ooolK0000
01P0oooo000X0?ooo`<00000o`3ooolZ0?ooobT00000<`3oool002P0oooo00<000000?ooo`3oool0
o`3oool10?ooobT00000G03oool002P0oooo00<000000?ooo`3oool0i@3ooolK000008D0oooo000X
0?ooo`030000003oool0oooo0<X0oooo6`00002P0?ooo`00:03oool00`000000oooo0?ooo`2_0?oo
oa/00000^`3oool002P0oooo00<000000?ooo`3oool0V`3ooolD00000=H0oooo000X0?ooo`030000
003oool0oooo08d0oooo3P00003Z0?ooo`007`3ooooo0000094000000@3oool002P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`h0000000<0oooo0000003oool02@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo000X0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo1`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo000X0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0<P3oool2000003H0oooo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`080?ooo`00:03oool00`000000oooo0?ooo`1W0?ooo`800000o`3ooolM0?ooo`00:03o
ool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0?l0oooo7@3oool002P0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`3o0?oooah0oooo000X0?ooo`<00000I03oool00`00
0000oooo0?ooo`3o0?oooal0oooo000X0?ooo`030000003oool0oooo0680oooo0P00003o0?ooob80
oooo000X0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0o`3ooolR0?ooo`00:03o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0?l0oooo8`3oool002P0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`3o0?ooob@0oooo000X0?ooo`030000003oool0oooo
05d0oooo0P00003o0?ooobL0oooo000X0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3o
ool0o`3ooolW0?ooo`00:03oool3000005/0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00:03o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0?l0oooo:@3oool002P0oooo00<00000
0?ooo`3oool0F03oool200000?l0oooo;03oool002P0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`3o0?ooob`0oooo000X0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool0o`3oool]0?ooo`00:03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0?l0oooo
;P3oool002P0oooo00<000000?ooo`3oool0D`3oool200000?l0oooo<@3oool002P0oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?oooc40oooo000X0?ooo`<00000D@3oool00`00
0000oooo0?ooo`3o0?oooc80oooo000X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool0o`3ooolc0?ooo`00:03oool00`000000oooo0?ooo`1>0?ooo`800000o`3ooolf0?ooo`00:03o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0?l0oooo=P3oool002P0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooocL0oooo000X0?ooo`030000003oool0oooo
04X0oooo0P00003o0?ooocX0oooo000X0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool0o`3ooolj0?ooo`00:03oool3000004P0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`00:03o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?l0oooo?03oool002P0oooo00<00000
0?ooo`3oool0A@3oool200000?l0oooo?`3oool000030?ooo`000000000000D000000`3oool40000
00D0oooo100000050?ooo`@000001`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
0?l0oooo?`3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0oooo@03oool0
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0?l0oooo@@3oool000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`100?ooo`800000o`3ooom40?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`040?ooo`@00000?P3oool00`000000oooo0?ooo`3o0?oood@0
oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`3o0?ooodD0oooo00040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`3o0?ooodH0oooo00020?ooo`<000001@3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0k0?ooo`800000o`3o
oom90?ooo`00103oool00`000000oooo0?ooo`040?ooo`@000001@3oool4000000D0oooo10000007
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0o`3ooom90?ooo`00:03oool00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo0?l0ooooBP3oool002P0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`3o0?oood/0oooo000X0?ooo`<00000=P3oool200000?l0oooo
CP3oool002P0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3o0?ooodh0oooo000X
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0o`3ooom?0?ooo`00:03oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0ooooC`3oool002P0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`3o0?oooe00oooo000X0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0o`3ooom@0?ooo`00:03oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo0?l0ooooD03oool002P0oooo0`00000b0?ooo`030000003oool0oooo0?l0ooooD@3oool0
02P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3o0?oooe40oooo000X0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00:03oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0?l0ooooD@3oool002P0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`3o0?oooe80oooo000X0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0o`3ooomB0?ooo`00:03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
0?l0ooooDP3oool002P0oooo0`00000`0?ooo`030000003oool0oooo0?l0ooooD`3oool002P0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3o0?oooe<0oooo000X0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool0o`3ooomC0?ooo`00:03oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo0?l0ooooE03oool002P0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`3o0?oooe@0oooo000X0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0o`3ooomD0?ooo`00:03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0?l0oooo
E03oool002P0oooo0`00000^0?ooo`030000003oool0oooo0?l0ooooE@3oool002P0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?oooeD0oooo000X0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`00:03oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo0?l0ooooEP3oool000030?ooo`000000000000D000000P3oool6000000@0oooo
100000050?ooo`@000001`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0oooo
EP3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0ooooEP3oool000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0o`3ooomG0?ooo`00103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`3o0?oooeL0oooo00040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0103oool4000002/0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`00103oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo100000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0oooo
F03oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?oooeP0oooo0002
0?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?oooeP0oooo00040?ooo`030000003oool0oooo
00@0oooo100000050?ooo`D00000103oool4000000L0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`3o0?oooeP0oooo000X0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0o`3ooomI0?ooo`00:03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo
F@3oool002P0oooo0`00000Z0?ooo`030000003oool0oooo0?l0ooooF@3oool002P0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?oooeX0oooo000X0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`00:03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0?l0ooooFP3oool002P0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`3o0?oooe/0oooo000X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0o`3o
oomK0?ooo`00:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0ooooF`3oool0
02P0oooo0`00000X0?ooo`030000003oool0oooo0?l0ooooF`3oool002P0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`3o0?oooe`0oooo000X0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0o`3ooomL0?ooo`00:03oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo0?l0ooooG03oool002P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3o
0?oooed0oooo000X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0o`3ooomM0?oo
o`00:03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0ooooG@3oool002P0oooo
0`00000U0?ooo`030000003oool0oooo0?l0ooooGP3oool002P0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`3o0?oooeh0oooo000X0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0o`3ooomN0?ooo`00:03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
0?l0ooooGP3oool002P0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3o0?oooel0
oooo000X0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0o`3ooomO0?ooo`00:03o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0ooooG`3oool002P0oooo0`00000S
0?ooo`030000003oool0oooo0?l0ooooH03oool002P0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`3o0?ooof00oooo000X0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0o`3ooomP0?ooo`00:03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0oooo
H@3oool000030?ooo`000000000000D000000`3oool4000000D0oooo100000050?ooo`@000001`3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0ooooH@3oool000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0?l0ooooH@3oool000@0oooo00<000000?ooo`3oool0203o
ool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?ooof80
oooo00040?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000040?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`@00000803oool00`00
0000oooo0?ooo`3o0?ooof80oooo00040?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooomR0?ooo`00103oool00`00
0000oooo0?ooo`040?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0o`3ooomR0?ooo`00103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0ooooH`3oool0
0080oooo0`0000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo0?l0ooooH`3oool000@0oooo00<000000?ooo`3oool0103oool50000
00@0oooo100000050?ooo`@000001`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0?l0ooooH`3oool002P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?ooof@0
oooo000X0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`00:03o
ool3000001l0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`00:03oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0?l0ooooI@3oool002P0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`3o0?ooofD0oooo000X0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0o`3ooomU0?ooo`00:03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0oooo
I@3oool002P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?ooofH0oooo000X
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooomV0?ooo`00:03oool30000
01d0oooo00<000000?ooo`3oool0o`3ooomV0?ooo`00:03oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo0?l0ooooI`3oool002P0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`3o0?ooofL0oooo000X0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0o`3o
oomW0?ooo`00:03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0ooooJ03oool0
02P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?ooofP0oooo000X0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0o`3ooomX0?ooo`00:03oool3000001X0oooo
00<000000?ooo`3oool0o`3ooomY0?ooo`00:03oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo0?l0ooooJ@3oool002P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3o
0?ooofT0oooo000X0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0o`3ooomY0?oo
o`00:03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0ooooJP3oool002P0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?ooofX0oooo000X0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0o`3ooomZ0?ooo`00:03oool3000001P0oooo00<00000
0?ooo`3oool0o`3ooom[0?ooo`00:03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
0?l0ooooJ`3oool002P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o0?ooof/0
oooo000X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0o`3ooom/0?ooo`0000<0
oooo0000000000001@0000050?ooo`030000003oool0oooo00@0oooo100000050?ooo`@000001`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0ooooK03oool000@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`3o0?ooof`0oooo00040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0ooooK03oool000@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`040?ooo`@000005@3oool00`000000oooo0?ooo`3o0?ooofd0oooo0004
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0?l0ooooK@3oool000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?ooofd0oooo00040?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0?l0ooooKP3oool00080oooo0`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0ooooKP3oool000@0oooo
00<000000?ooo`3oool00`3oool6000000@0oooo1@0000040?ooo`@000001`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0?l0ooooKP3oool002P0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`3o0?ooofl0oooo000X0?ooo`<00000503oool00`000000oooo0?ooo`3o
0?ooofl0oooo000X0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooom_0?oo
o`00:03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0ooooL03oool002P0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooog00oooo000X0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0o`3ooom`0?ooo`00:03oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0?l0ooooL03oool002P0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`3o0?ooog40oooo000X0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0o`3oooma0?ooo`00:03oool300000180oooo00<000000?ooo`3oool0o`3oooma0?ooo`00:03o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooLP3oool002P0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooog80oooo000X0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0o`3ooomb0?ooo`00:03oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0?l0ooooL`3oool002P0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`3o0?ooog<0oooo000X0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3o
oomc0?ooo`00:03oool300000100oooo00<000000?ooo`3oool0o`3ooomc0?ooo`00:03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooM03oool002P0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`3o0?ooog@0oooo000X0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0o`3ooomd0?ooo`00:03oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0?l0ooooM@3oool002P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o
0?ooogD0oooo000X0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooome0?oo
o`00:03oool3000000d0oooo00<000000?ooo`3oool0o`3ooomf0?ooo`00:03oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooMP3oool002P0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`3o0?ooogH0oooo000X0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0o`3ooomg0?ooo`0000<0oooo000000000000100000040?ooo`@000001@3oool40000
00D0oooo100000070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooomg0?oo
o`0000<0oooo0000003oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?oo
o`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooomg0?ooo`000P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooomg0?ooo`000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`@000002P3oool00`000000
oooo0?ooo`3o0?ooogP0oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oo
ogP0oooo00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooogP0oooo00000`3o
ool000000?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?ooogT0oooo00000`3oool000000?oo
o`030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`3o0?ooogT0oooo00020?ooo`@000001@3oool4000000D0
oooo100000050?ooo`@000001`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0
ooooN@3oool002P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooogX0oooo
000X0?ooo`<000002@3oool00`000000oooo0?ooo`3o0?ooogX0oooo000X0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`00:03oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0?l0ooooNP3oool002P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`3o0?ooog/0oooo000X0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
o`3ooomk0?ooo`00:03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooN`3o
ool002P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooog`0oooo000X0?oo
o`<000001`3oool00`000000oooo0?ooo`3o0?ooog`0oooo000X0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0o`3oooml0?ooo`00:03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0?l0ooooO@3oool002P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`3o0?ooogd0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooomm
0?ooo`00:03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooO@3oool002P0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooogh0oooo000X0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooomn0?ooo`00:03oool3000000D0oooo00<0
00000?ooo`3oool0o`3ooomn0?ooo`00:03oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0?l0ooooO`3oool002P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oo
ogl0oooo000X0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00
:03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooP03oool002P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooh00oooo000X0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0o`3ooon00?ooo`00:03oool300000080oooo00<000000?oo
o`3oool0o`3ooon10?ooo`00:03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0
ooooP@3oool002P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oooh40oooo
00000`3oool0000000000004000000<0oooo1P0000040?ooo`@000001@3oool4000000L0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oooh40oooo00000`3oool000000?ooo`03
0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3o
ool0oooo0000003o0?oooh@0oooo00020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool02P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool01@00
0000oooo0?ooo`3oool000000?l0ooooQ03oool000<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`04
0?ooo`050000003oool0oooo0?ooo`000000o`3ooon40?ooo`00103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00@0oooo1000003o0?ooohD0oooo00050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00`3oool4000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo00000?l0ooooQ@3oool000030?ooo`000000oooo00<0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000
o`3ooon50?ooo`0000<0oooo0000003oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0000003o0?ooohH0oooo00020?ooo`@000001@3o
ool4000000D0oooo1@0000040?ooo`@000001`3oool00`000000oooo0000003o0?ooohH0oooo000X
0?ooo`030000003oool000000?l0ooooQP3oool002P0oooo00<000000?ooo`000000o`3ooon60?oo
o`00:03oool300000?l0ooooQP3oool002P0oooo0P00003o0?ooohL0oooo000X0?ooo`800000o`3o
oon70?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohH0oooo000X0?ooo`030000003oool0oooo
0?l0ooooQP3oool002P0oooo00<000000?ooo`3oool0o`3ooon60?ooo`00:03oool00`000000oooo
0?ooo`3o0?ooohH0oooo000X0?ooo`<00000o`3ooon60?ooo`00:03oool00`000000oooo0?ooo`3o
0?ooohH0oooo000X0?ooo`030000003oool0oooo0?l0ooooQP3oool002P0oooo00<000000?ooo`3o
ool0o`3ooon60?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0.24579, 565.877, 0.0275961, \
10.4676}}],

Cell[BoxData[
    \({2253.3271791387842`, 975.2531599870887`, 695.6520110548977`, 
      602.6597739569061`, 635.892488705563`, 648.0391282861631`, 
      644.6733658935121`, 636.920863884124`}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112245 0.136054 -0.200185 0.000356585 [
[.15986 .05475 -3 -9 ]
[.15986 .05475 3 0 ]
[.29592 .05475 -3 -9 ]
[.29592 .05475 3 0 ]
[.43197 .05475 -3 -9 ]
[.43197 .05475 3 0 ]
[.56803 .05475 -3 -9 ]
[.56803 .05475 3 0 ]
[.70408 .05475 -3 -9 ]
[.70408 .05475 3 0 ]
[.84014 .05475 -3 -9 ]
[.84014 .05475 3 0 ]
[.97619 .05475 -3 -9 ]
[.97619 .05475 3 0 ]
[.01131 .1564 -24 -4.5 ]
[.01131 .1564 0 4.5 ]
[.01131 .24555 -24 -4.5 ]
[.01131 .24555 0 4.5 ]
[.01131 .33469 -24 -4.5 ]
[.01131 .33469 0 4.5 ]
[.01131 .42384 -24 -4.5 ]
[.01131 .42384 0 4.5 ]
[.01131 .51299 -24 -4.5 ]
[.01131 .51299 0 4.5 ]
[.01131 .60213 -24 -4.5 ]
[.01131 .60213 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 .06725 m
.15986 .0735 L
s
[(2)] .15986 .05475 0 1 Mshowa
.29592 .06725 m
.29592 .0735 L
s
[(3)] .29592 .05475 0 1 Mshowa
.43197 .06725 m
.43197 .0735 L
s
[(4)] .43197 .05475 0 1 Mshowa
.56803 .06725 m
.56803 .0735 L
s
[(5)] .56803 .05475 0 1 Mshowa
.70408 .06725 m
.70408 .0735 L
s
[(6)] .70408 .05475 0 1 Mshowa
.84014 .06725 m
.84014 .0735 L
s
[(7)] .84014 .05475 0 1 Mshowa
.97619 .06725 m
.97619 .0735 L
s
[(8)] .97619 .05475 0 1 Mshowa
.125 Mabswid
.05102 .06725 m
.05102 .071 L
s
.07823 .06725 m
.07823 .071 L
s
.10544 .06725 m
.10544 .071 L
s
.13265 .06725 m
.13265 .071 L
s
.18707 .06725 m
.18707 .071 L
s
.21429 .06725 m
.21429 .071 L
s
.2415 .06725 m
.2415 .071 L
s
.26871 .06725 m
.26871 .071 L
s
.32313 .06725 m
.32313 .071 L
s
.35034 .06725 m
.35034 .071 L
s
.37755 .06725 m
.37755 .071 L
s
.40476 .06725 m
.40476 .071 L
s
.45918 .06725 m
.45918 .071 L
s
.48639 .06725 m
.48639 .071 L
s
.51361 .06725 m
.51361 .071 L
s
.54082 .06725 m
.54082 .071 L
s
.59524 .06725 m
.59524 .071 L
s
.62245 .06725 m
.62245 .071 L
s
.64966 .06725 m
.64966 .071 L
s
.67687 .06725 m
.67687 .071 L
s
.73129 .06725 m
.73129 .071 L
s
.7585 .06725 m
.7585 .071 L
s
.78571 .06725 m
.78571 .071 L
s
.81293 .06725 m
.81293 .071 L
s
.86735 .06725 m
.86735 .071 L
s
.89456 .06725 m
.89456 .071 L
s
.92177 .06725 m
.92177 .071 L
s
.94898 .06725 m
.94898 .071 L
s
.25 Mabswid
0 .06725 m
1 .06725 L
s
.02381 .1564 m
.03006 .1564 L
s
[(1000)] .01131 .1564 1 0 Mshowa
.02381 .24555 m
.03006 .24555 L
s
[(1250)] .01131 .24555 1 0 Mshowa
.02381 .33469 m
.03006 .33469 L
s
[(1500)] .01131 .33469 1 0 Mshowa
.02381 .42384 m
.03006 .42384 L
s
[(1750)] .01131 .42384 1 0 Mshowa
.02381 .51299 m
.03006 .51299 L
s
[(2000)] .01131 .51299 1 0 Mshowa
.02381 .60213 m
.03006 .60213 L
s
[(2250)] .01131 .60213 1 0 Mshowa
.125 Mabswid
.02381 .08508 m
.02756 .08508 L
s
.02381 .10291 m
.02756 .10291 L
s
.02381 .12074 m
.02756 .12074 L
s
.02381 .13857 m
.02756 .13857 L
s
.02381 .17423 m
.02756 .17423 L
s
.02381 .19206 m
.02756 .19206 L
s
.02381 .20989 m
.02756 .20989 L
s
.02381 .22772 m
.02756 .22772 L
s
.02381 .26338 m
.02756 .26338 L
s
.02381 .28121 m
.02756 .28121 L
s
.02381 .29903 m
.02756 .29903 L
s
.02381 .31686 m
.02756 .31686 L
s
.02381 .35252 m
.02756 .35252 L
s
.02381 .37035 m
.02756 .37035 L
s
.02381 .38818 m
.02756 .38818 L
s
.02381 .40601 m
.02756 .40601 L
s
.02381 .44167 m
.02756 .44167 L
s
.02381 .4595 m
.02756 .4595 L
s
.02381 .47733 m
.02756 .47733 L
s
.02381 .49516 m
.02756 .49516 L
s
.02381 .53082 m
.02756 .53082 L
s
.02381 .54864 m
.02756 .54864 L
s
.02381 .56647 m
.02756 .56647 L
s
.02381 .5843 m
.02756 .5843 L
s
.02381 .04943 m
.02756 .04943 L
s
.02381 .0316 m
.02756 .0316 L
s
.02381 .01377 m
.02756 .01377 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.15986 .14758 L
.29592 .04787 L
.43197 .01472 L
.56803 .02657 L
.70408 .0309 L
.84014 .0297 L
.97619 .02693 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooohH0oooo000X0?ooo`030000003oool0oooo0?l0ooooQP3oool002P0oooo00<000000?oo
o`3oool0o`3ooon60?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohH0oooo000X0?ooo`030000
003oool0oooo0?l0ooooQP3oool002P0oooo0`00003o0?ooohH0oooo000X0?ooo`030000003oool0
oooo09l0oooo2000003N0?ooo`00:03oool00`000000oooo0?ooo`2K0?ooo`@00000203oool;0000
0=<0oooo000X0?ooo`030000003oool0oooo09L0oooo1000000G0?ooo`X00000b@3oool002P0oooo
00<000000?ooo`3oool0T`3oool4000002D0oooo2`00002n0?ooo`00:03oool00`000000oooo0?oo
o`0`0?ooo`H00000<P3oool400000280oooo1@00000<0?ooo`@00000903oool;00000080oooo1000
000d0?ooo`@00000<`3oool00`000000oooo0?ooo`0a0?ooo`@000002P3oool002P0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`@000004`3oool00`000000oooo0?ooo`0^
0?ooob0000006@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool06P3ooolL000000T0oooo000X0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0G0?ooo`@000005`3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo01L0ooooKP00000F0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01`3oool002P0oooo0`00000b0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool04`3oool4000001L0oooo1P00000e0?ooo`030000003oool0oooo0300oooo0P0000030?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo000X0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
=03oool200000180oooo1000000L0?ooo`040000003oool0oooo000003H0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo00000002000003@0oooo00<000000?ooo`3oool0<03oool4000000X0
oooo000X0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`0:0?ooo`D00000803oool010000000oooo0?ooo`00000b0?ooo`@00000<`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`00:03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`060?ooo`@000009P3oool00`000000oooo
0000000b0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool002P0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`@00000:P3oool00`000000oooo0000
000b0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`070?ooo`00:03oool00`000000oooo0?ooo`0a0?ooo`@00000<`3oool4000000030?ooo`000000
000000800000;`3oool200000380oooo1@00000e0?ooo`<00000;`3oool600000340oooo1000000:
0?ooo`00:03oool00`000000oooo0?ooo`1Z0?ooo`<00000o`3ooolI0?ooo`00:03oool3000006P0
oooo0P00003o0?oooa`0oooo000X0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0
o`3ooolL0?ooo`00:03oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0?l0oooo7@3o
ool002P0oooo00<000000?ooo`3oool0I03oool200000?l0oooo803oool002P0oooo00<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`3o0?ooob00oooo000X0?ooo`030000003oool0oooo0680
oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`00:03oool00`000000oooo0?ooo`1P0?ooo`800000
o`3ooolT0?ooo`007`3ooooo0000094000000@3oool002P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0P00000:0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool002P0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0U0?ooo`800000303oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool0203oool002P0oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`3o0?ooobP0oooo000X0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0
o`3ooolY0?ooo`00:03oool00`000000oooo0?ooo`1H0?ooo`800000o`3oool/0?ooo`00:03oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0?l0oooo;03oool002P0oooo0`00001F0?oo
o`030000003oool0oooo0?l0oooo;@3oool002P0oooo00<000000?ooo`3oool0E03oool200000?l0
oooo<03oool002P0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`3o0?oooc00oooo
000X0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3ooola0?ooo`00:03oool0
0`000000oooo0?ooo`1@0?ooo`800000o`3ooold0?ooo`00:03oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo0?l0oooo=03oool002P0oooo00<000000?ooo`3oool0C@3oool200000?l0
oooo=`3oool002P0oooo0`00001<0?ooo`030000003oool0oooo0?l0oooo=`3oool002P0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooocP0oooo000X0?ooo`030000003oool0
oooo04T0oooo0P00003o0?oooc/0oooo000X0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0o`3ooolk0?ooo`00:03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?l0
oooo?03oool002P0oooo00<000000?ooo`3oool0A@3oool200000?l0oooo?`3oool002P0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?ooocl0oooo000X0?ooo`<00000@`3oool0
0`000000oooo0?ooo`3o0?oood00oooo000X0?ooo`030000003oool0oooo0440oooo0P00003o0?oo
od<0oooo000X0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0o`3ooom30?ooo`00
:03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0?l0ooooA03oool002P0oooo00<0
00000?ooo`3oool0?@3oool200000?l0ooooA`3oool002P0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`3o0?ooodL0oooo000X0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0o`3ooom80?ooo`00:03oool3000003T0oooo0P00003o0?oood/0oooo000X0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`00:03oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo0?l0ooooC03oool002P0oooo00<000000?ooo`3oool0=@3oool2
00000?l0ooooC`3oool000030?ooo`000000000000D000000`3oool4000000D0oooo100000050?oo
o`@000001`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0ooooC`3oool000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0ooooC`3oool000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo0?l0ooooD03oool000@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool0103oool400000380oooo00<000000?ooo`3oool0
o`3ooom@0?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0o`3ooom@0?ooo`00
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool0o`3ooomA0?ooo`000P3oool3000000D0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`3o0?oooe40oooo00040?ooo`030000003oool0oooo00@0oooo100000050?ooo`@000001@3oool4
000000L0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3o0?oooe40oooo000X0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool0o`3ooomB0?ooo`00:03oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo0?l0ooooDP3oool002P0oooo0`00000a0?ooo`030000
003oool0oooo0?l0ooooDP3oool002P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`3o0?oooe<0oooo000X0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0o`3ooomC
0?ooo`00:03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0ooooD`3oool002P0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3o0?oooe@0oooo000X0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`00:03oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo0?l0ooooE03oool002P0oooo0`00000_0?ooo`030000003oool0
oooo0?l0ooooE03oool002P0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?oo
oeD0oooo000X0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`00
:03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0ooooE@3oool002P0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`3o0?oooeH0oooo000X0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0o`3ooomF0?ooo`00:03oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo0?l0ooooEP3oool002P0oooo0`00000/0?ooo`030000003oool0oooo0?l0
ooooE`3oool002P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?oooeL0oooo
000X0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`00:03oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0ooooE`3oool002P0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`3o0?oooeP0oooo000X0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool0o`3ooomH0?ooo`00:03oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo0?l0ooooF03oool002P0oooo0`00000Z0?ooo`030000003oool0oooo0?l0ooooF@3o
ool002P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?oooeT0oooo000X0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`00:03oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0ooooFP3oool000030?ooo`000000000000D00000
0P3oool6000000@0oooo100000050?ooo`@000001`3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0?l0ooooFP3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0
ooooFP3oool000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`00103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00T0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0
oooo1000000W0?ooo`030000003oool0oooo0?l0ooooF`3oool000@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0o`3ooomK0?ooo`00
103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo100000040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo0?l0ooooF`3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`3o0?oooe`0oooo00020?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?oooe`0oooo00040?oo
o`030000003oool0oooo00@0oooo100000050?ooo`D00000103oool4000000L0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`3o0?oooe`0oooo000X0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0o`3ooomM0?ooo`00:03oool3000002H0oooo00<000000?ooo`3oool0
o`3ooomM0?ooo`00:03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0ooooG@3o
ool002P0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?oooeh0oooo000X0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`00:03oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo0?l0ooooGP3oool002P0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`3o0?oooeh0oooo000X0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0o`3ooomO0?ooo`00:03oool3000002@0oooo00<000000?ooo`3oool0o`3ooomO
0?ooo`00:03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0ooooG`3oool002P0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3o0?ooof00oooo000X0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`00:03oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo0?l0ooooH03oool002P0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`3o0?ooof40oooo000X0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0o`3ooomQ0?ooo`00:03oool300000280oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`00
:03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0ooooH@3oool002P0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?ooof80oooo000X0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0o`3ooomR0?ooo`00:03oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo0?l0ooooHP3oool002P0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`3o0?ooof<0oooo000X0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
o`3ooomS0?ooo`00:03oool300000200oooo00<000000?ooo`3oool0o`3ooomS0?ooo`00:03oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0ooooI03oool002P0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`3o0?ooof@0oooo000X0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0o`3ooomT0?ooo`0000<0oooo0000000000001@0000030?ooo`@00000
1@3oool4000000D0oooo100000070?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
o`3ooomT0?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`00
103oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo0?l0ooooI@3oool000@0oooo00<000000?ooo`3oool0203oool01@000000
oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?ooofD0oooo00040?oo
o`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`@00000703oool00`000000oooo0?oo
o`3o0?ooofH0oooo00040?ooo`030000003oool0oooo00@0oooo100000040?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?ooofH0oooo00040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0o`3ooomV0?ooo`000P3oool3000000H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`00103oool0
0`000000oooo0?ooo`040?ooo`D00000103oool4000000D0oooo100000070?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`00:03oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo0?l0ooooI`3oool002P0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`3o0?ooofL0oooo000X0?ooo`<000006`3oool00`000000oooo0?ooo`3o0?ooofP0oooo
000X0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0o`3ooomX0?ooo`00:03oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0ooooJ03oool002P0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`3o0?ooofT0oooo000X0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0o`3ooomY0?ooo`00:03oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo0?l0ooooJ@3oool002P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`3o0?ooofX0oooo000X0?ooo`<000006@3oool00`000000oooo0?ooo`3o0?ooofX0oooo000X0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooomZ0?ooo`00:03oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0ooooJ`3oool002P0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`3o0?ooof/0oooo000X0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0o`3ooom[0?ooo`00:03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0?l0ooooJ`3oool002P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?oo
of`0oooo000X0?ooo`<000005`3oool00`000000oooo0?ooo`3o0?ooof`0oooo000X0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0o`3ooom/0?ooo`00:03oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo0?l0ooooK@3oool002P0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`3o0?ooofd0oooo000X0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0o`3ooom]0?ooo`00:03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0
ooooKP3oool002P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3o0?ooofh0oooo
000X0?ooo`<000005@3oool00`000000oooo0?ooo`3o0?ooofh0oooo000X0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`00:03oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo0?l0ooooK`3oool002P0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`3o0?ooofl0oooo00000`3oool0000000000005000000D0oooo00<000000?ooo`3oool0
103oool4000000D0oooo100000070?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
o`3ooom_0?ooo`00103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0ooooL03oool000@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
o`3ooom`0?ooo`00103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo1000000B0?ooo`030000
003oool0oooo0?l0ooooL03oool000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0o`3oooma0?ooo`00103oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo100000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooL@3o
ool000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0o`3oooma0?ooo`000P3oool3000000D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0o`3oooma0?ooo`00103oool00`000000oooo0?ooo`030?ooo`H00000103oool5000000@0
oooo100000070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooomb0?ooo`00
:03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooLP3oool002P0oooo0`00
000A0?ooo`030000003oool0oooo0?l0ooooLP3oool002P0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`3o0?ooog<0oooo000X0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0o`3ooomc0?ooo`00:03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0
ooooL`3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooog@0oooo
000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooomd0?ooo`00:03oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooM03oool002P0oooo0`00000?0?oo
o`030000003oool0oooo0?l0ooooM03oool002P0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`3o0?ooogD0oooo000X0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
o`3ooome0?ooo`00:03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0ooooM@3o
ool002P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooogH0oooo000X0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooomf0?ooo`00:03oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooMP3oool002P0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`3o0?ooogL0oooo000X0?ooo`<00000303oool00`000000oooo0?oo
o`3o0?ooogL0oooo000X0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooomg
0?ooo`00:03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooM`3oool002P0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooogP0oooo000X0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooomh0?ooo`00:03oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0?l0ooooN03oool002P0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`3o0?ooogT0oooo000X0?ooo`<000002P3oool00`000000oooo0?ooo`3o0?oo
ogT0oooo000X0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooomi0?ooo`00
:03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooooNP3oool000030?ooo`00
0000000000@00000103oool4000000D0oooo100000050?ooo`@000001`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0?l0ooooNP3oool000030?ooo`000000oooo00<0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0?l0ooooNP3oool00080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0?l0ooooN`3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooN`3oool0
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103o
ool4000000L0oooo00<000000?ooo`3oool0o`3ooomk0?ooo`001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0o`3ooomk0?ooo`0000<0oooo0000003oool00`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0o`3oooml0?ooo`0000<0oooo0000003oool00`3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3o
ooml0?ooo`000P3oool4000000D0oooo100000050?ooo`@000001@3oool4000000L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooog`0oooo000X0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00:03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0?l0ooooO@3oool002P0oooo0`0000060?ooo`030000003oool0oooo0?l0oooo
O@3oool002P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooogh0oooo000X
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooomn0?ooo`00:03oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooOP3oool002P0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`3o0?ooogh0oooo000X0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0o`3ooomo0?ooo`00:03oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0?l0ooooO`3oool002P0oooo0`0000040?ooo`030000003oool0oooo0?l0ooooO`3oool0
02P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooh00oooo000X0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooon00?ooo`00:03oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0?l0ooooP03oool002P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`3o0?oooh40oooo000X0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0o`3ooon10?ooo`00:03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0?l0ooooP@3oool002P0oooo0`0000020?ooo`030000003oool0oooo0?l0ooooP@3oool002P0oooo
00D000000?ooo`3oool0oooo0000003o0?oooh@0oooo000X0?ooo`050000003oool0oooo0?ooo`00
0000o`3ooon40?ooo`00:03oool01@000000oooo0?ooo`3oool000000?l0ooooQ03oool002P0oooo
00@000000?ooo`3oool00000o`3ooon50?ooo`00:03oool010000000oooo0?ooo`00003o0?ooohD0
oooo000X0?ooo`040000003oool0oooo00000?l0ooooQ@3oool002P0oooo0`00003o0?ooohH0oooo
000X0?ooo`030000003oool000000?l0ooooQP3oool002P0oooo00<000000?ooo`000000o`3ooon6
0?ooo`00:03oool00`000000oooo0000003o0?ooohH0oooo00000`3oool0000000000004000000<0
oooo1P0000040?ooo`@000001@3oool4000000L0oooo0P00003o0?ooohL0oooo00000`3oool00000
0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo0P00003o
0?ooohL0oooo00020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool200000?l0ooooQ`3oool0
00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`@00000o`3ooon50?ooo`00103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooon60?ooo`001@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo100000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooohH0oooo00000`3oool0
00000?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?l0ooooQP3oool000030?ooo`000000oooo00<0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooon60?oo
o`000P3oool4000000D0oooo100000050?ooo`D00000103oool4000000L0oooo00<000000?ooo`3o
ool0o`3ooon60?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohH0oooo000X0?ooo`030000003o
ool0oooo0?l0ooooQP3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0.24579, 496.236, 0.0275961, \
10.5292}}],

Cell[BoxData[
    \({12371.37677702673`, 5136.653137780861`, 3711.9964313009423`, 
      3651.5286722506853`, 3601.2898422439234`, 3596.649040770707`, 
      3648.953200936657`, 4083.2717957666746`}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112245 0.136054 -0.226546 6.70794e-005 [
[.15986 .02927 -3 -9 ]
[.15986 .02927 3 0 ]
[.29592 .02927 -3 -9 ]
[.29592 .02927 3 0 ]
[.43197 .02927 -3 -9 ]
[.43197 .02927 3 0 ]
[.56803 .02927 -3 -9 ]
[.56803 .02927 3 0 ]
[.70408 .02927 -3 -9 ]
[.70408 .02927 3 0 ]
[.84014 .02927 -3 -9 ]
[.84014 .02927 3 0 ]
[.97619 .02927 -3 -9 ]
[.97619 .02927 3 0 ]
[.01131 .17593 -24 -4.5 ]
[.01131 .17593 0 4.5 ]
[.01131 .31009 -24 -4.5 ]
[.01131 .31009 0 4.5 ]
[.01131 .44425 -30 -4.5 ]
[.01131 .44425 0 4.5 ]
[.01131 .57841 -30 -4.5 ]
[.01131 .57841 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 .04177 m
.15986 .04802 L
s
[(2)] .15986 .02927 0 1 Mshowa
.29592 .04177 m
.29592 .04802 L
s
[(3)] .29592 .02927 0 1 Mshowa
.43197 .04177 m
.43197 .04802 L
s
[(4)] .43197 .02927 0 1 Mshowa
.56803 .04177 m
.56803 .04802 L
s
[(5)] .56803 .02927 0 1 Mshowa
.70408 .04177 m
.70408 .04802 L
s
[(6)] .70408 .02927 0 1 Mshowa
.84014 .04177 m
.84014 .04802 L
s
[(7)] .84014 .02927 0 1 Mshowa
.97619 .04177 m
.97619 .04802 L
s
[(8)] .97619 .02927 0 1 Mshowa
.125 Mabswid
.05102 .04177 m
.05102 .04552 L
s
.07823 .04177 m
.07823 .04552 L
s
.10544 .04177 m
.10544 .04552 L
s
.13265 .04177 m
.13265 .04552 L
s
.18707 .04177 m
.18707 .04552 L
s
.21429 .04177 m
.21429 .04552 L
s
.2415 .04177 m
.2415 .04552 L
s
.26871 .04177 m
.26871 .04552 L
s
.32313 .04177 m
.32313 .04552 L
s
.35034 .04177 m
.35034 .04552 L
s
.37755 .04177 m
.37755 .04552 L
s
.40476 .04177 m
.40476 .04552 L
s
.45918 .04177 m
.45918 .04552 L
s
.48639 .04177 m
.48639 .04552 L
s
.51361 .04177 m
.51361 .04552 L
s
.54082 .04177 m
.54082 .04552 L
s
.59524 .04177 m
.59524 .04552 L
s
.62245 .04177 m
.62245 .04552 L
s
.64966 .04177 m
.64966 .04552 L
s
.67687 .04177 m
.67687 .04552 L
s
.73129 .04177 m
.73129 .04552 L
s
.7585 .04177 m
.7585 .04552 L
s
.78571 .04177 m
.78571 .04552 L
s
.81293 .04177 m
.81293 .04552 L
s
.86735 .04177 m
.86735 .04552 L
s
.89456 .04177 m
.89456 .04552 L
s
.92177 .04177 m
.92177 .04552 L
s
.94898 .04177 m
.94898 .04552 L
s
.25 Mabswid
0 .04177 m
1 .04177 L
s
.02381 .17593 m
.03006 .17593 L
s
[(6000)] .01131 .17593 1 0 Mshowa
.02381 .31009 m
.03006 .31009 L
s
[(8000)] .01131 .31009 1 0 Mshowa
.02381 .44425 m
.03006 .44425 L
s
[(10000)] .01131 .44425 1 0 Mshowa
.02381 .57841 m
.03006 .57841 L
s
[(12000)] .01131 .57841 1 0 Mshowa
.125 Mabswid
.02381 .07531 m
.02756 .07531 L
s
.02381 .10885 m
.02756 .10885 L
s
.02381 .14239 m
.02756 .14239 L
s
.02381 .20947 m
.02756 .20947 L
s
.02381 .24301 m
.02756 .24301 L
s
.02381 .27655 m
.02756 .27655 L
s
.02381 .34363 m
.02756 .34363 L
s
.02381 .37717 m
.02756 .37717 L
s
.02381 .41071 m
.02756 .41071 L
s
.02381 .47779 m
.02756 .47779 L
s
.02381 .51133 m
.02756 .51133 L
s
.02381 .54487 m
.02756 .54487 L
s
.02381 .00823 m
.02756 .00823 L
s
.02381 .61195 m
.02756 .61195 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.15986 .11802 L
.29592 .02245 L
.43197 .0184 L
.56803 .01503 L
.70408 .01472 L
.84014 .01822 L
.97619 .04736 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00H`3oool600000300oooo1000000b0?ooo`@00000<03oool400000380
oooo1000000c0?ooo`030000003oool0oooo0300oooo100000090?ooo`00<@3oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`00<@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`00<@3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0;@3oool6000003@0oooo00<00000
0?ooo`3oool0;P3oool2000000<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00340oooo0`00000b0?oo
o`030000003oool0oooo0380oooo0P00000a0?ooo`040000003oool0oooo000003D0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo00000002000003@0oooo00<000000?ooo`3oool0;`3oool4
000000T0oooo000a0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0^0?ooo`040000003oool0oooo00000340oooo1000000a0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo000a0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`000000<@3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo000a0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0000000J0?ooofX000005`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`00<@3oool00`000000oooo0?ooo`0`0?ooo`@00000<@3oool4000002L0oooo
:000000G0?ooo`D00000<`3oool3000001P0oooo7@00000`0?ooo`@000002@3oool00340oooo00<0
00000?ooo`3oool0MP3ooolJ00000:l0oooo1@00000h0?ooo`00<@3oool00`000000oooo0?ooo`1X
0?ooo`h00000cP3oool5000003<0oooo000a0?ooo`030000003oool0oooo06H0oooo0P00003Q0?oo
o`@00000;`3oool00340oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3U0?ooo`D0
0000:P3oool00340oooo00<000000?ooo`3oool0H`3oool200000>d0oooo1@00000U0?ooo`00<@3o
ool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0?80oooo1@00000P0?ooo`00<@3oool0
0`000000oooo0?ooo`1P0?ooo`800000nP3oool5000001/0oooo000a0?ooo`030000003oool0oooo
05l0oooo00<000000?ooo`3oool0o`3oool4000001L0oooo000X0?ooool00000R@0000000340oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
0P00000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00D000000P3oool00`000000oooo0?ooo`080?ooo`00<@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0000000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo0`00000:0?ooo`00<@3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02@0oooo0P00000=0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`080?ooo`00<@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0oooo8P3oool00340oooo00<000000?ooo`3o
ool0EP3oool200000?l0oooo9@3oool00340oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`3o0?ooobD0oooo000a0?ooo`030000003oool0oooo05<0oooo0P00003o0?ooobP0oooo000a
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00<@3oool00`00
0000oooo0?ooo`1@0?ooo`800000o`3oool[0?ooo`00<@3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0?l0oooo:`3oool00340oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`3o0?ooob`0oooo000a0?ooo`030000003oool0oooo04`0oooo0P00003o0?ooobl0oooo000a
0?ooo`<00000B`3oool00`000000oooo0?ooo`3o0?ooobl0oooo000a0?ooo`030000003oool0oooo
04T0oooo0P00003o0?oooc80oooo000a0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool0o`3ooolb0?ooo`00<@3oool00`000000oooo0?ooo`160?ooo`800000o`3ooole0?ooo`00<@3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0?l0oooo=@3oool00340oooo00<00000
0?ooo`3oool0@`3oool200000?l0oooo>03oool00340oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`3o0?ooocP0oooo000a0?ooo`030000003oool0oooo0400oooo0P00003o0?oooc/0
oooo000a0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`00<@3o
ool00`000000oooo0?ooo`0m0?ooo`800000o`3oooln0?ooo`00<@3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo0?l0oooo?P3oool00340oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`3o0?ooocl0oooo000a0?ooo`030000003oool0oooo03T0oooo0P00003o0?oood80
oooo000a0?ooo`<00000>03oool00`000000oooo0?ooo`3o0?oood80oooo000a0?ooo`030000003o
ool0oooo03H0oooo0P00003o0?ooodD0oooo000a0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0o`3ooom50?ooo`00<@3oool00`000000oooo0?ooo`0c0?ooo`800000o`3ooom80?oo
o`00<@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0?l0ooooB03oool00340oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000a0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool0o`3ooom90?ooo`00<@3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo0?l0ooooB@3oool00340oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`3o0?ooodT0oooo000a0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0o`3ooom90?ooo`00<@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0oooo
BP3oool00340oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3o0?ooodX0oooo000a
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0o`3ooom:0?ooo`00<@3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo0?l0ooooB`3oool00340oooo0`00000_0?ooo`03
0000003oool0oooo0?l0ooooB`3oool00340oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`3o0?oood/0oooo000a0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0o`3o
oom;0?ooo`00<@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0ooooC03oool0
0340oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?oood`0oooo000a0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00<@3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo0?l0ooooC03oool00340oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`3o0?ooodd0oooo000a0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0o`3ooom=0?ooo`00303oool4000000@0oooo100000050?ooo`@000001@3oool40000
00L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`3o0?ooodd0oooo000;0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0
000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?ooodh0oooo000;0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`3o0?ooodh0oooo000;0?ooo`8000000`3oool010000000oooo
0?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo0?l0ooooCP3oool000/0oooo00<000000?ooo`0000000P0000030?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`040?ooo`@00000:`3oool00`000000oooo0?ooo`3o0?ooodh0oooo000;
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?ooodl0oooo000<0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`3o0?ooodl0oooo000=0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`3o0?ooodl0oooo000>0?ooo`<000000`3oool4000000D0oooo100000050?ooo`@0
00001`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0ooooD03oool00340oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?oooe00oooo000a0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0o`3ooom@0?ooo`00<@3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0?l0ooooD03oool00340oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`3o0?oooe40oooo000a0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0o`3ooomA0?ooo`00<@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo
D@3oool00340oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3o0?oooe80oooo000a
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`00<@3oool30000
02P0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`00<@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo0?l0ooooDP3oool00340oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`3o0?oooe<0oooo000a0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0o`3o
oomC0?ooo`00<@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0ooooD`3oool0
0340oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?oooe<0oooo000a0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`00<@3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0?l0ooooE03oool00340oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`3o0?oooe@0oooo000a0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0o`3ooomE0?ooo`00<@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
0?l0ooooE@3oool00340oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?oooeD0
oooo000a0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`00<@3o
ool3000002@0oooo00<000000?ooo`3oool0o`3ooomF0?ooo`00<@3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0?l0ooooEP3oool00340oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`3o0?oooeH0oooo000a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0o`3ooomG0?ooo`00<@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0?l0oooo
E`3oool00340oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3o0?oooeL0oooo000a
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`00<@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0ooooF03oool00340oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`3o0?oooeP0oooo000a0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0o`3ooomH0?ooo`00<@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0?l0ooooF@3oool00340oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o
0?oooeT0oooo000a0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooomI0?oo
o`00<@3oool300000240oooo00<000000?ooo`3oool0o`3ooomI0?ooo`00<@3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo0?l0ooooFP3oool00340oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`3o0?oooeX0oooo000a0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0o`3ooomJ0?ooo`00<@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0?l0ooooF`3oool00340oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?oooe/0
oooo000a0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3ooomK0?ooo`00<@3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0ooooF`3oool00340oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?oooe`0oooo000a0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`002`3oool4000000D0oooo100000050?ooo`@0
00001@3oool4000000L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?oooe`0
oooo000:0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0ooooG03oool0
00X0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooomM0?ooo`002P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
00@0oooo1000000L0?ooo`030000003oool0oooo0?l0ooooG@3oool000/0oooo100000040?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0o`3ooomM0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`3o0?oooeh0oooo000:0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0?l0ooooGP3oool000X0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0o`3o
oomN0?ooo`002`3oool4000000D0oooo100000050?ooo`@000001@3oool4000000L0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`3o0?oooeh0oooo000a0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0o`3ooomO0?ooo`00<@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo0?l0ooooG`3oool00340oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`3o0?oooel0oooo000a0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0o`3o
oomP0?ooo`00<@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0ooooH03oool0
0340oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3o0?ooof00oooo000a0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`00<@3oool3000001T0oooo
00<000000?ooo`3oool0o`3ooomQ0?ooo`00<@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo0?l0ooooH@3oool00340oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o
0?ooof40oooo000a0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooomR0?oo
o`00<@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0ooooHP3oool00340oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o0?ooof80oooo000a0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`00<@3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0?l0ooooH`3oool00340oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`3o0?ooof<0oooo000a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0o`3ooomS0?ooo`00<@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0oooo
H`3oool00340oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?ooof@0oooo000a
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`00<@3oool30000
01H0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`00<@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo0?l0ooooI@3oool00340oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`3o0?ooofD0oooo000a0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3o
oomU0?ooo`00<@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0ooooI@3oool0
0340oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooofH0oooo000a0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooomV0?ooo`00<@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0?l0ooooIP3oool00340oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`3o0?ooofL0oooo000a0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0o`3ooomW0?ooo`00<@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
0?l0ooooI`3oool00340oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooofL0
oooo000a0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0o`3ooomX0?ooo`00<@3o
ool300000180oooo00<000000?ooo`3oool0o`3ooomX0?ooo`00<@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0?l0ooooJ03oool00340oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`3o0?ooofT0oooo000a0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0o`3ooomY0?ooo`00<@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0oooo
J@3oool00340oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooofT0oooo000a
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooomZ0?ooo`00<@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooJP3oool00340oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`3o0?ooofX0oooo000a0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0o`3ooomZ0?ooo`0000<0oooo0000000000001@0000030?ooo`@000001@3o
ool4000000D0oooo100000050?ooo`@000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0?l0ooooJ`3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`3o0?ooof/0oooo00040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooom[0?ooo`00103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0103oool4000000d0oooo00<000000?ooo`3oool0o`3ooom/0?ooo`00103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0?l0ooooK03oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`3o0?ooof`0oooo00040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo
000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooom/0?ooo`000P3oool3000000D0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`00103oool00`00
0000oooo0?ooo`040?ooo`@000001@3oool4000000D0oooo100000050?ooo`@000001`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooK@3oool00340oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`3o0?ooofd0oooo000a0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0o`3ooom^0?ooo`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0?l0ooooKP3oool00340oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o
0?ooofh0oooo000a0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooom^0?oo
o`00<@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooK`3oool00340oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooofl0oooo000a0?ooo`<000002`3o
ool00`000000oooo0?ooo`3o0?ooofl0oooo000a0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0o`3ooom`0?ooo`00<@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0?l0ooooL03oool00340oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?ooog00
oooo000a0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooom`0?ooo`00<@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooooL@3oool00340oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooog40oooo000a0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0o`3oooma0?ooo`00<@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0?l0ooooLP3oool00340oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`3o0?ooog80oooo000a0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3o
oomb0?ooo`00<@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooLP3oool0
0340oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooog<0oooo000a0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`00<@3oool3000000L0oooo
00<000000?ooo`3oool0o`3ooomc0?ooo`00<@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0?l0ooooL`3oool00340oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o
0?ooog@0oooo000a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooomd0?oo
o`00<@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooM03oool00340oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooogD0oooo000a0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0o`3ooome0?ooo`00<@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0?l0ooooM@3oool00340oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3o0?ooogD0oooo000a0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0o`3ooomf0?ooo`00<@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo
MP3oool00340oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooogH0oooo000a
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooomg0?ooo`00<@3oool30000
00<0oooo00<000000?ooo`3oool0o`3ooomg0?ooo`00<@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0?l0ooooM`3oool00340oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`3o0?ooogL0oooo000a0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3o
oomh0?ooo`00<@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooN03oool0
0340oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooogP0oooo000a0?ooo`05
0000003oool0oooo0?ooo`000000o`3ooomk0?ooo`00<@3oool01@000000oooo0?ooo`3oool00000
0?l0ooooN`3oool00340oooo00D000000?ooo`3oool0oooo0000003o0?ooog/0oooo00000`3oool0
00000000000500000080oooo1P0000040?ooo`@000001@3oool4000000D0oooo100000070?ooo`05
0000003oool0oooo0?ooo`000000o`3ooomk0?ooo`00103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`00003o0?ooog`0oooo00040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool010000000
oooo0?ooo`00003o0?ooog`0oooo00040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00
003o0?ooog`0oooo00040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool0103oool400000?l0ooooO03oool000@0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`040?ooo`030000003oool000000?l0ooooO@3oool000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`000000o`3ooomm0?ooo`000P3oool3000000D0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000
003oool000000?l0ooooO@3oool000@0oooo00<000000?ooo`3oool0103oool4000000D0oooo1000
00050?ooo`@000001@3oool4000000L0oooo0P00003o0?ooogh0oooo000a0?ooo`800000o`3ooomn
0?ooo`00<@3oool200000?l0ooooOP3oool00340oooo0P00003o0?ooogh0oooo000a0?ooo`030000
003oool0oooo0?l0ooooO@3oool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool0
0`000000oooo0?ooo`3o0?ooogd0oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00340
oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool300000?l0ooooO@3oool00340oooo00<0
00000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0.0609105, 2868.25, \
0.0282395, 57.2769}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Best symbolic polynomials from layer's 1 and 2.", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(xso[1]\)[\([1]\)]\), "\[IndentingNewLine]", 
    \(FullSimplify@\(xso[2]\)[\([1]\)]\)}], "Input"],

Cell[BoxData[
    \(\(\(4.2118460115651475`\)\(\[InvisibleSpace]\)\) + 
      22.582786418223098`\ x1 - 16.96606941533943`\ x1\^2 + 
      6.1141004542769375`\ x4 + 0.35752719088834684`\ x1\ x4 + 
      5.0061219373888965`\ x4\^2\)], "Output"],

Cell[BoxData[
    \(\(-5.9712444550524815`\) + 3.8204163754494123`\ x1\^2 + 
      x1\ \((\(-5.998419112176627`\) - 0.5088436201559687`\ x2)\) + 
      5.663106860859016`\ \((\(-1.6310836807621447`\) + 
            x2)\)\ \((\(\(0.1467458983247966`\)\(\[InvisibleSpace]\)\) + 
            x2)\) + 0.04755913615053424`\ \((\(\(3.593402060915295`\)\(\
\[InvisibleSpace]\)\) - 10.127903158361114`\ \((\(-1.5700956447374161`\) + \
x1)\)\ x1 + 22.284163742131458`\ x2 + 1.3489416862535848`\ x1\ x2 - \
15.012865673701224`\ x2\^2)\)\^2 + 1.8992928653331507`\ x4\^2 - 
      1.7449905570968207`\ \((\(-4.343353486845531`\) + 
            x5)\)\ \((\(\(1.2131616560911394`\)\(\[InvisibleSpace]\)\) + 
            x5)\) + x4\ \((\(\(7.1116760522401865`\)\(\[InvisibleSpace]\)\) + 
            7.203509972923733`\ x5)\) - 
      0.002089789513545822`\ \((\(\(3.593402060915295`\)\(\[InvisibleSpace]\)\
\) - 10.127903158361114`\ \((\(-1.5700956447374161`\) + x1)\)\ x1 + 
            22.284163742131458`\ x2 + 1.3489416862535848`\ x1\ x2 - 
            15.012865673701224`\ x2\^2)\)\ \((\(\(7.715301453181163`\)\(\
\[InvisibleSpace]\)\) + 
            1.5937048847624795`\ x4\ \((\(\(3.744380965171869`\)\(\
\[InvisibleSpace]\)\) + x4)\) + 4.583318118576324`\ x5 + 
            6.044496475939777`\ x4\ x5 - 1.4642291483687508`\ x5\^2)\) - 
      0.007850110776695212`\ \((\(\(7.715301453181163`\)\(\[InvisibleSpace]\)\
\) + 1.5937048847624795`\ x4\ \
\((\(\(3.744380965171869`\)\(\[InvisibleSpace]\)\) + x4)\) + \
4.583318118576324`\ x5 + 6.044496475939777`\ x4\ x5 - 1.4642291483687508`\ x5\
\^2)\)\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Output of layer one's best symbolic polynomials in Fortran and C form.\
\>", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CForm@\(xso[1]\)[\([1]\)]\)], "Input"],

Cell["\<\
4.2118460115651475 + 22.582786418223098*x1 - 
   16.96606941533943*Power(x1,2) + 6.1141004542769375*x4 + 
   0.35752719088834684*x1*x4 + 5.0061219373888965*Power(x4,2)\
\>", "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FortranForm@\(xso[1]\)[\([1]\)]\)], "Input"],

Cell["\<\
        4.2118460115651475 + 22.582786418223098*x1 - 
     -  16.96606941533943*x1**2 + 6.1141004542769375*x4 + 
     -  0.35752719088834684*x1*x4 + 5.0061219373888965*x4**2\
\>", "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculation of data set using symbolic GMDH solution.", "Section"],

Cell[BoxData[
    \(\(zpolypredictGMDH = \(GMDHeval[4, #] &\)\  /@ \ xdata;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Validation of symbolic GMDH solution over validation set.", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\(zpolypredictGMDH1000 = 
        Take[zpolypredictGMDH, {401, 1400}];\)\n
    \(zze1000 = zpolypredictGMDH1000 - \(xva[5]\)[\([1]\)];\)\n
    zze1000 . zze1000\)\)\)], "Input"],

Cell[BoxData[
    \(3.095292976860945`*^-26\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

Plot of symbolic solution vs add10. 
Sorted on add10.\
\>", "Section"],

Cell[BoxData[
    \(<< Graphics`MultipleListPlot`\)], "Input"],

Cell[BoxData[{
    \(\(zvaVSzpoly = 
        Transpose@
          Sort[Drop[Transpose[{zdata, zpolypredictGMDH}], 
              0]];\)\), "\[IndentingNewLine]", 
    \(\(MultipleListPlot[zvaVSzpoly[\([1]\)], zvaVSzpoly[\([2]\)], 
        PlotJoined \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[
    \(<< Statistics`LinearRegression`\)], "Input"],

Cell[BoxData[
    \(\(data = 
        Transpose[{\(xtr[1]\)[\([1]\)], \(xtr[1]\)[\([2]\)], 
            ztr}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(Table[\(Regress[
              data, {1, x1, x2, x1\ x2, x1\ x1, \ x2\ x2}, {x1, 
                x2}];\), {1000}];\)]\)], "Input"],

Cell[BoxData[
    \({9.515999999999998`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(Table[\(GMDHleastSquares[{\(xtr[1]\)[\([1]\)], \(xtr[
                    1]\)[\([2]\)], ztr}];\), {1000}];\)]\)], "Input"],

Cell[BoxData[
    \({1.1869999999999976`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 933}},
WindowSize->{1271, 929},
WindowMargins->{{0, Automatic}, {4, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 24, 0, 141, "Title"],
Cell[1803, 55, 3350, 54, 1555, "Text"],

Cell[CellGroupData[{
Cell[5178, 113, 72, 0, 109, "Section"],

Cell[CellGroupData[{
Cell[5275, 117, 403, 7, 198, "Input"],
Cell[5681, 126, 38, 1, 41, "Output"]
}, Open  ]],
Cell[5734, 130, 434, 7, 198, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6205, 142, 61, 0, 109, "Section"],
Cell[6269, 144, 4540, 85, 1316, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10846, 234, 92, 2, 109, "Section"],

Cell[CellGroupData[{
Cell[10963, 240, 92, 1, 42, "Input"],
Cell[11058, 243, 135, 3, 35, "Print"],
Cell[11196, 248, 135, 3, 35, "Print"],
Cell[11334, 253, 135, 3, 35, "Print"],
Cell[11472, 258, 135, 3, 35, "Print"],
Cell[11610, 263, 135, 3, 35, "Print"],
Cell[11748, 268, 135, 3, 35, "Print"],
Cell[11886, 273, 135, 3, 35, "Print"],
Cell[12024, 278, 135, 3, 35, "Print"],
Cell[12162, 283, 60, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12271, 290, 91, 2, 109, "Section"],

Cell[CellGroupData[{
Cell[12387, 296, 91, 1, 42, "Input"],
Cell[12481, 299, 135, 3, 35, "Print"],
Cell[12619, 304, 135, 3, 35, "Print"],
Cell[12757, 309, 135, 3, 35, "Print"],
Cell[12895, 314, 135, 3, 35, "Print"],
Cell[13033, 319, 135, 3, 35, "Print"],
Cell[13171, 324, 135, 3, 35, "Print"],
Cell[13309, 329, 135, 3, 35, "Print"],
Cell[13447, 334, 135, 3, 35, "Print"],
Cell[13585, 339, 60, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13694, 346, 63, 0, 109, "Section"],

Cell[CellGroupData[{
Cell[13782, 350, 522, 9, 250, "Input"],
Cell[14307, 361, 208, 3, 41, "Output"],
Cell[14518, 366, 31243, 643, 279, 4223, 305, "GraphicsData", "PostScript", \
"Graphics"],
Cell[45764, 1011, 207, 3, 41, "Output"],
Cell[45974, 1016, 30138, 628, 279, 4130, 302, "GraphicsData", "PostScript", \
"Graphics"],
Cell[76115, 1646, 212, 3, 41, "Output"],
Cell[76330, 1651, 29137, 572, 279, 3532, 251, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[105516, 2229, 66, 0, 109, "Section"],

Cell[CellGroupData[{
Cell[105607, 2233, 120, 2, 68, "Input"],
Cell[105730, 2237, 243, 4, 43, "Output"],
Cell[105976, 2243, 1605, 25, 178, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[107630, 2274, 97, 2, 109, "Section"],

Cell[CellGroupData[{
Cell[107752, 2280, 58, 1, 42, "Input"],
Cell[107813, 2283, 193, 4, 84, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[108043, 2292, 64, 1, 42, "Input"],
Cell[108110, 2295, 199, 4, 84, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[108358, 2305, 72, 0, 109, "Section"],
Cell[108433, 2307, 90, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[108560, 2313, 76, 0, 109, "Section"],

Cell[CellGroupData[{
Cell[108661, 2317, 224, 4, 120, "Input"],
Cell[108888, 2323, 57, 1, 43, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[108994, 2330, 81, 4, 187, "Section"],
Cell[109078, 2336, 62, 1, 42, "Input"],
Cell[109143, 2339, 314, 7, 94, "Input"],
Cell[109460, 2348, 64, 1, 42, "Input"],
Cell[109527, 2351, 125, 3, 42, "Input"],

Cell[CellGroupData[{
Cell[109677, 2358, 160, 3, 42, "Input"],
Cell[109840, 2363, 68, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[109945, 2369, 152, 2, 42, "Input"],
Cell[110100, 2373, 69, 1, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

